California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 71 - STEM CELL RESEARCH. FUNDING. BONDS. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1271457 | PROGRESSIVE ALLIANCE AGAINST PROP. 71 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1271520 | FOCUS ON THE FAMILY CALIFORNIA COMMITTEE AGAINST PROPOSITION 71 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1268971 | CALIFORNIANS AGAINST LOAN AND CLONE, NO ON PROP 71 - SPONSORED BY THE CATHOLIC COMMON GOOD FOUNDATION OF CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1267017 | DOCTORS PATIENTS AND TAXPAYERS FOR FISCAL RESPONSIBILITY - NO ON 71 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1260661 | YES ON 71: COALITION FOR STEM CELL RESEARCH AND CURES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1282095 | PHYSICIANS FOR COMPASSIONATE CARE OF CALIFORNIA, INC. | OPPOSE